@@ -52,6 +52,7 @@ class CreateInitialRevisionsAppLabelTest(TestModelMixin, TestBase):
 
 
 class CreateInitialRevisionsDbTest(TestModelMixin, TestBase):
+    databases = {"default", "mysql", "postgres"}
 
     def testCreateInitialRevisionsDb(self):
         obj = TestModel.objects.create()
@@ -67,6 +68,7 @@ class CreateInitialRevisionsDbTest(TestModelMixin, TestBase):
 
 
 class CreateInitialRevisionsModelDbTest(TestModelMixin, TestBase):
+    databases = {"default", "postgres"}
 
     def testCreateInitialRevisionsModelDb(self):
         obj = TestModel.objects.db_manager("postgres").create()
@@ -134,6 +136,7 @@ class DeleteRevisionsAppLabelTest(TestModelMixin, TestBase):
 
 
 class DeleteRevisionsDbTest(TestModelMixin, TestBase):
+    databases = {"default", "mysql", "postgres"}
 
     def testDeleteRevisionsDb(self):
         with reversion.create_revision(using="postgres"):
@@ -155,6 +158,7 @@ class DeleteRevisionsDbTest(TestModelMixin, TestBase):
 
 
 class DeleteRevisionsModelDbTest(TestModelMixin, TestBase):
+    databases = {"default", "postgres"}
 
     def testDeleteRevisionsModelDb(self):
         with reversion.create_revision():
